/****************************************************************************
*   COPYRIGHT 2019 All rights reserved
*   Panasonic Industrial Devices Europe GmbH
****************************************************************************/

#include "application.h"
#include "ble_api_message.h"
#include "uart_api.h"
#include "version_specific.h"
#include "debug.h"

/* from osal.h and osal.c */
struct receive_message {
  struct bt_cmn_msg msg;            /*!< Message Header*/
  uint8_t data[MAX_BUFFER_SIZE]; /*!< Message */
};

static struct receive_message message;

int ble_application_get_message_callback(struct bt_cmn_msg **bt_cmn_msg, uint8_t **data)
{
  uint32_t length = sizeof(message.data);
  uint32_t msg_len;
  int ret;

  *bt_cmn_msg = NULL;
  *data = (uint8_t *)&message.data[0];

  ret = uart_application_check_data_available_callback();
  if (ret) {
    return 1;
  }

  ret = uart_application_receive_receive_bytes(*data, 3, UART_MAX_TCU_CMD_TIMEOUT);
  if (ret) {
    return -1;
  }

  msg_len = (*data)[0];
  msg_len |= ((*data)[1] << 8);
  msg_len |= ((*data)[2] << 16);

  if (length < msg_len) {
    warning("length %d out of bounds\n", length);
    return -1;
  }

  /* the length bytes have already been received */
  ret = uart_application_receive_receive_bytes((*data) + 3, msg_len - 3, UART_MAX_TCU_CMD_TIMEOUT);
  if (ret) {
    return -1;
  }

  message.msg.module_id = FAT_IF_MOD_ID;
  *bt_cmn_msg = (struct bt_cmn_msg *)&message.msg;

  return 0;
}

void ble_application_release_memory_callback(struct bt_cmn_msg *bt_cmn_msg, uint8_t *data)
{
  memset((bt_cmn_msg), 0, sizeof(struct bt_cmn_msg));
  memset((data), 0, sizeof(message.data));
  dprintf("\n");
  //	__debugbreak();
}

void ble_application_event_handling_failed_callback(uint8_t service_id, uint8_t opcode, uint8_t error)
{
  xprintf("service_id %02x, opcode %02x, error %02x\n", service_id, opcode, error);
  __debugbreak();
}

void ble_application_default_event_callback(struct bt_cmn_msg *bt_cmn_msg, uint8_t *data)
{
  dprintf("\n");
  //	__debugbreak();
}

void ble_application_uart_message_callback(struct bt_cmn_msg *bt_cmn_msg, uint8_t *data)
{
  dprintf("\n");
  //	__debugbreak();
}

void ble_application_timer_message_callback(struct bt_cmn_msg *bt_cmn_msg, uint8_t *data)
{
  dprintf("\n");
  //	__debugbreak();
}
