/****************************************************************************
*   COPYRIGHT 2019 All rights reserved
*   Panasonic Industrial Devices Europe GmbH
****************************************************************************/

#include "application.h"
#include "timer_api.h"

VOID CALLBACK TimerCallback(_In_ PVOID lpParameter, _In_ BOOLEAN TimerOrWaitFired)
{
  struct timer_data *data = (struct timer_data *)lpParameter;
  BOOL ret;

  HANDLE timer_handle = (HANDLE)data->priv;
  ret = DeleteTimerQueueTimer(NULL, timer_handle, NULL);
  if (ret == FALSE) {
    DWORD error = GetLastError();
    if (error != ERROR_IO_PENDING) {
      dprintf("DeleteTimerQueueTimer() failed\n");
    }
  }

  data->function(data->argument);
  dprintf("TimerCallback()...\n");
}

int timer_start(struct timer_data *data, uint32_t timeout)
{
  HANDLE timer_handle;
  BOOL ret;

  ret = CreateTimerQueueTimer(&timer_handle, NULL, TimerCallback, data, timeout, 0, WT_EXECUTEDEFAULT);
  if (ret == FALSE) {
    dprintf("CreateTimerQueueTimer() failed\n");
    return -1;
  }

  data->priv = (void *)timer_handle;
  dprintf("%p %llx\n", data->priv, (uint64_t)timer_handle);
  return 0;
}

int timer_stop(struct timer_data *data)
{
  HANDLE timer_handle;
  BOOL ret;

  /* gracefully handle a stop of a non-exisiting timer */
  if (!data->priv) {
    return 0;
  }

  timer_handle = (HANDLE)data->priv;
  dprintf("%p %llx\n", data->priv, (uint64_t)timer_handle);

  ret = DeleteTimerQueueTimer(NULL, timer_handle, NULL);
  if (ret == FALSE) {
    dprintf("DeleteTimerQueueTimer() failed\n");
    return -1;
  }

  data->priv = NULL;

  return 0;
}
