/****************************************************************************
*   COPYRIGHT 2019 All rights reserved
*   Panasonic Industrial Devices Europe GmbH
****************************************************************************/

#ifndef __DEBUG_H__
#define __DEBUG_H__

/**
* @file configurations/host_mode/bluetooth-sdk/include/debug.h
* @brief Header file that describes the debug environment for the host mode applications
* @details This header files describes the debug environment that is needed by the Bluetooth SDK.
*
**/

#include "types.h"

/*! Empty definition of the warning() macro. This is used by nvm_usr_api_flash.c. Remove this when nvm_usr_api_flash.c
 * is changed. */
#define warning(...)

/*! Definition of a warning macro that will output directly to the console */
#define bs_warning(...)                                                                                                               \
  do {                                                                                                                                \
    printf("%s(): ", __func__);                                                                                                       \
    printf(__VA_ARGS__);                                                                                                              \
  } while (0)

/*! Definition of an empty macro - we are not interested in GATT warning messages */
#define gatt_bs_printf(...)
/*! Definition of an empty macro - we are not interested in GAP warning messages */
#define gap_bs_printf(...)
/*! Definition of an empty macro - we are not interested in SMP warning messages */
#define smp_bs_printf(...)
/*! Definition of an empty macro - we are not interested in SPP warning messages */
#define spp_bs_printf(...)
/*! Definition of an empty macro - we are not interested in vendor warning messages */
#define ven_bs_printf(...)
/*! Definition of an empty macro - we are not interested in HCI warning messages */
#define hci_bs_printf(...)
/*! Definition of an empty macro - we are not interested in buffer warning messages */
#define buff_bs_printf(...)
/*! Definition of an empty macro - we are not interested in TCU warning messages */
#define tcu_bs_printf(...)

/*! We include application-specific code from the SDK, which then does not include any application-specific header file.
This macro is used to output debug stuff at some points, so define it here. */
#define vPrintf(...)

#endif
