/****************************************************************************
*   COPYRIGHT 2019 All rights reserved
*   Panasonic Industrial Devices Europe GmbH
****************************************************************************/

#include "application.h"
#include "ble_api_smp.h"

int ble_application_smp_pairing_request_callback(enum ble_smp_device_role role, uint16_t connection_handle,
                                                 enum tcu_le_smp_authentication_requirements authentication_requirement)
{
  dprintf("connection_handle %04x, role %02x, authentication_requirement %02x\n", connection_handle, role, authentication_requirement);

  if (role == SMP_SLAVE) {
    ble_api_smp_slv_accept_pairing_event(connection_handle, authentication_requirement);
  } else {
    ble_api_smp_master_accept_pairing_request(connection_handle, authentication_requirement);
  }

  return 0;
}

void ble_application_smp_status_callback(enum tcu_le_smp_status  status, uint16_t connection_handle)
{
  dprintf("connection_handle %04x, status %02x\n", connection_handle, status);

  if (status == STATUS_SUCCESS) {
    //    application.is_encrypted = true;
    //    application.encryption_setup_failed = false;
    xprintf("ENCRYPTION_OK\n");
    return;
  }

  //  application.is_encrypted = false;
  //  application.encryption_setup_failed = true;
  xprintf("ENCRYPTION_FAILED\n");
}

void ble_application_smp_key_distribution_callback(uint8_t *initiator_key, uint8_t *responder_key)
{
  *initiator_key = SMP_LTK_ENABLED | SMP_IRK_ENABLED;
  *responder_key = SMP_LTK_ENABLED | SMP_IRK_ENABLED;
  dprintf("\n");
}

void ble_application_smp_capability_callback(enum tcu_le_smp_io_capabilities *io_capabilities)
{
  *io_capabilities = SMP_IO_CAP_NO_IP_NO_OP;
  dprintf("\n");
}

void ble_application_smp_oob_data_available_callback(uint16_t connection_handle,
                                                     enum tcu_le_smp_slv_mas_oob_authentication_data_available *own_flag,
                                                     enum tcu_le_smp_slv_mas_oob_authentication_data_available *remote_flag)
{
  *own_flag = SMP_OOB_DATA_NOT_PRESENT;
  *remote_flag = SMP_OOB_DATA_NOT_PRESENT;
  dprintf("\n");
}

void ble_application_smp_key_entry_callback(uint16_t connection_handle, uint32_t key, uint8_t pass_key_entry_method)
{
  dprintf("\n");
  __debugbreak();
}

void ble_application_smp_key_press_notification_event_callback(uint16_t connection_handle, uint8_t notification_type)
{
  dprintf("\n");
  __debugbreak();
}

void ble_application_smp_oob_data_entry_callback(uint16_t connection_handle, uint8_t pass_key_entry_method)
{
  dprintf("\n");
  __debugbreak();
}

void ble_application_smp_sec_con_oob_data_request_event_callback(uint16_t connection_handle, uint8_t pass_key_entry_method)
{
  dprintf("\n");
  __debugbreak();
}

void ble_application_smp_remote_oob_data_request_callback(uint16_t connection_handle, uint8_t *remote_rand_value,
                                                          uint8_t *remote_confirm_value)
{
  dprintf("\n");
  __debugbreak();
}

void ble_application_smp_peer_device_identity_address_received_event_callback(enum tcu_le_smp_address_type peer_address_type, uint8_t *peer_identity_address)
{
  dprintf("\n");
  __debugbreak();
}