/*
 * COPYRIGHT (C) 2019
 * TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION ALL RIGHTS RESERVED
 *
 * THE SOURCE CODE AND ITS RELATED DOCUMENTATION IS PROVIDED "AS IS". TOSHIBA
 * ELECTRONIC DEVICES & STORAGE CORPORATION MAKES NO OTHER WARRANTY OF ANY KIND,
 * WHETHER EXPRESS, IMPLIED OR, STATUTORY AND DISCLAIMS ANY AND ALL IMPLIED
 * WARRANTIES OF MERCHANTABILITY, SATISFACTORY QUALITY, NON INFRINGEMENT AND
 * FITNESS FOR A PARTICULAR PURPOSE.
 *
 * THE SOURCE CODE AND DOCUMENTATION MAY INCLUDE ERRORS. TOSHIBA ELECTRONIC
 * DEVICES & STORAGE CORPORATION RESERVES THE RIGHT TO INCORPORATE MODIFICATIONS
 * TO THE SOURCE CODE IN LATER REVISIONS OF IT, AND TO MAKE IMPROVEMENTS OR
 * CHANGES IN THE DOCUMENTATION OR THE PRODUCTS OR TECHNOLOGIES DESCRIBED
 * THEREIN AT ANY TIME.
 *
 * TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION SHALL NOT BE LIABLE FOR ANY
 * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGE OR LIABILITY ARISING FROM YOUR USE
 * OF THE SOURCE CODE OR ANY DOCUMENTATION, INCLUDING BUT NOT LIMITED TO, LOST
 * REVENUES, DATA OR PROFITS, DAMAGES OF ANY SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL NATURE, PUNITIVE DAMAGES, LOSS OF PROPERTY OR LOSS OF PROFITS
 * ARISING OUT OF OR IN CONNECTION WITH THIS AGREEMENT, OR BEING UNUSABLE, EVEN
 * IF ADVISED OF THE POSSIBILITY OR PROBABILITY OF SUCH DAMAGES AND WHETHER
 * A CLAIM FOR SUCH DAMAGE IS BASED UPON WARRANTY, CONTRACT, TORT, NEGLIGENCE OR
 * OTHERWISE.
 */

/**
* @file server_spp_over_ble_api.h
*
* @brief Contains definitions and function declarations for the SPP over BLE profile implementation.
*/
#ifndef __SERVER_SPP_OVER_BLE_API_H__
#define __SERVER_SPP_OVER_BLE_API_H__

#include "types.h"
#include "ble_api.h"

/*! SPP over BLE status enumeration */
enum spp_over_ble_status {
  SPP_OVER_BLE_SUCCESS,
  SPP_OVER_BLE_FAILED
};

/*! Global SPP over BLE profile data structure */
extern struct ble_api_srv_profile spp_over_ble_profile;

/**
* @brief Initialises the SPP over BLE profile.
*/
int spp_over_ble_profile_init(const uint8_t *device_name, uint16_t device_name_length); 

/**
* @brief Sends data. After the call spp_over_ble_sent_callback()
* must be awaited.
*
* @param[in] buf Data buffer to send
* @param[in] length Length of data buffer
* @param[in] connection_handle Connection Identifier
*/
int spp_over_ble_send(uint8_t *buf, uint16_t length, uint16_t connection_handle);

/**
* @brief Callback functions that provides the sent
* status of the previous spp_over_ble_send() call.
*
* @param[in] status Send status
* @param[in] connection_handle Connection Identifier
*/
extern void spp_over_ble_sent_callback(enum spp_over_ble_status status, uint16_t connection_handle);

/**
* @brief Receive callback function.
*
* @param[in] buf Data buffer to send
* @param[in] length Length of data buffer
* @param[in] connection_handle Connection Identifier
*/
extern void spp_over_ble_receive_callback(uint8_t *buf, uint16_t length, uint16_t connection_handle);

/**
* @brief Connect callback function.
*
* @param[in] *bd_addr Pointer to Bluetooth device address of device that has connected
* @param[in] connection_handle Connection Identifier
* @param[in] max_packet_size Maximum size of packet that can be transferred using spp_over_ble_send().
*/
extern void spp_over_ble_connect_callback(uint8_t *bd_addr, uint16_t connection_handle, uint16_t max_packet_size);

/**
* @brief MTU Change event callback function.
*
* @param[in] *bd_addr Pointer to Bluetooth device address of device that has connected
* @param[in] connection_handle Connection Identifier
* @param[in] max_packet_size Maximum size of packet that can be transferred using spp_over_ble_send().
*/
extern void spp_over_ble_mtu_changed_callback(uint8_t *bd_addr, uint16_t connection_handle, uint16_t max_packet_size);

/**
* @brief Disconnect callback function.
*
* @param[in] connection_handle Connection Identifier
*/
extern void spp_over_ble_disconnect_callback(uint16_t connection_handle);

#endif

