/*
 * COPYRIGHT (C) 2019
 * TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION ALL RIGHTS RESERVED
 *
 * THE SOURCE CODE AND ITS RELATED DOCUMENTATION IS PROVIDED "AS IS". TOSHIBA
 * ELECTRONIC DEVICES & STORAGE CORPORATION MAKES NO OTHER WARRANTY OF ANY KIND,
 * WHETHER EXPRESS, IMPLIED OR, STATUTORY AND DISCLAIMS ANY AND ALL IMPLIED
 * WARRANTIES OF MERCHANTABILITY, SATISFACTORY QUALITY, NON INFRINGEMENT AND
 * FITNESS FOR A PARTICULAR PURPOSE.
 *
 * THE SOURCE CODE AND DOCUMENTATION MAY INCLUDE ERRORS. TOSHIBA ELECTRONIC
 * DEVICES & STORAGE CORPORATION RESERVES THE RIGHT TO INCORPORATE MODIFICATIONS
 * TO THE SOURCE CODE IN LATER REVISIONS OF IT, AND TO MAKE IMPROVEMENTS OR
 * CHANGES IN THE DOCUMENTATION OR THE PRODUCTS OR TECHNOLOGIES DESCRIBED
 * THEREIN AT ANY TIME.
 *
 * TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION SHALL NOT BE LIABLE FOR ANY
 * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGE OR LIABILITY ARISING FROM YOUR USE
 * OF THE SOURCE CODE OR ANY DOCUMENTATION, INCLUDING BUT NOT LIMITED TO, LOST
 * REVENUES, DATA OR PROFITS, DAMAGES OF ANY SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL NATURE, PUNITIVE DAMAGES, LOSS OF PROPERTY OR LOSS OF PROFITS
 * ARISING OUT OF OR IN CONNECTION WITH THIS AGREEMENT, OR BEING UNUSABLE, EVEN
 * IF ADVISED OF THE POSSIBILITY OR PROBABILITY OF SUCH DAMAGES AND WHETHER
 * A CLAIM FOR SUCH DAMAGE IS BASED UPON WARRANTY, CONTRACT, TORT, NEGLIGENCE OR
 * OTHERWISE.
 */

#include "server_spp_over_ble_api.h"
#include "ble_api_slave.h"
#include "characteristic_gap_appearance.h"
#include "characteristic_model_number_string.h"
#include "characteristic_gap_device_name.h"
#include "debug_api.h"

static uint8_t profile_adv_name[0x1f] = "SPP_BLE"; /* If user want EEPROM device name don't configure this */
static uint16_t profile_adv_name_length = 7;

extern struct ble_api_srv_service service_generic_access;
extern struct ble_api_srv_service service_spp_over_ble;
extern struct ble_api_srv_service service_device_information;

static struct ble_api_srv_service *services[] = {
    &service_generic_access,
    &service_device_information,
    &service_spp_over_ble,
};

static enum ble_api_result init(struct ble_api_srv_profile *profile)
{
  g_characteristic_gap_appearance.category = APPEARANCE_CATEGORY_UNKNOWN;
  return LE_API_SUCCESS;
}

static enum ble_api_result profile_init_done(struct ble_api_srv_profile *profile)
{
  advertising_data.server = profile;
  advertising_data.use_appearance = 0;
  advertising_data.advertising_name = &profile_adv_name[0];    /* If user want EEPROM device name don't configure this */
  advertising_data.adv_name_length = profile_adv_name_length;  /* If user want EEPROM device name don't configure this */
  advertising_data.advertising_interval_minimum = LE_ADVERTISING_INTERVAL_MINIMUM;
  advertising_data.advertising_interval_maximum = LE_ADVERTISING_INTERVAL_MAXIMUM;

  return LE_API_SUCCESS;
}

static void connected_callback(uint8_t *bd_addr, uint16_t connection_handle, uint16_t mtu_size)
{
  spp_over_ble_connect_callback(bd_addr, connection_handle, (mtu_size - 3));
  gap_bs_printf("\n");
}

static void disconnected_callback(uint8_t *bd_addr, uint16_t connection_handle)
{
  spp_over_ble_disconnect_callback(connection_handle);
  gap_bs_printf("\n");
}

static void mtu_changed_callback(uint8_t *bd_addr, uint16_t connection_handle, uint16_t mtu_size)
{
  spp_over_ble_mtu_changed_callback(bd_addr, connection_handle, (mtu_size - 3));
}

static struct ble_api_srv_profile_ram spp_over_ble_profile_ram[MAXIMUM_DEVICES];

struct ble_api_srv_profile spp_over_ble_profile = {
    {
     services,
     sizeof(services) / sizeof(services[0]),
     SMP_AUTH_NO_MITM_NO_BONDING,
     init,
     profile_init_done,
     connected_callback,
     disconnected_callback,
     mtu_changed_callback,
    },
    &spp_over_ble_profile_ram[0],
};

int spp_over_ble_profile_init(const uint8_t *device_name, uint16_t device_name_length)
{
  enum ble_api_result result;

  if (device_name) {
    memcpy(profile_adv_name, device_name, device_name_length);
    profile_adv_name_length = device_name_length;
  }

  result = ble_api_srv_profile_init(&spp_over_ble_profile);
  if (result != LE_API_SUCCESS) {
    gatt_bs_printf("ble_api_srv_profile_init() failed\n");
    return -1;
  }

  return 0;
}

